@@ -451,12 +451,15 @@ class DirectSystemCalls(interfaces.plugins.PluginInterface):
 
                 address, disasm_bytes = syscall_info
 
-                yield 0, (
-                    proc_name,
-                    proc.UniqueProcessId,
-                    vad_path,
-                    format_hints.Hex(address),
-                    disasm_bytes,
+                yield (
+                    0,
+                    (
+                        proc_name,
+                        proc.UniqueProcessId,
+                        vad_path,
+                        format_hints.Hex(address),
+                        disasm_bytes,
+                    ),
                 )
 
     def run(self) -> renderers.TreeGrid:
