@@ -648,12 +648,15 @@ class Skeleton_Key_Check(interfaces.plugins.PluginInterface):
                     csystem, cryptdll_base, cryptdll_size
                 )
 
-            yield 0, (
-                lsass_proc.UniqueProcessId,
-                "lsass.exe",
-                skeleton_key_present,
-                format_hints.Hex(csystem.Initialize),
-                format_hints.Hex(csystem.Decrypt),
+            yield (
+                0,
+                (
+                    lsass_proc.UniqueProcessId,
+                    "lsass.exe",
+                    skeleton_key_present,
+                    format_hints.Hex(csystem.Initialize),
+                    format_hints.Hex(csystem.Decrypt),
+                ),
             )
 
     def _lsass_proc_filter(self, proc):
