@@ -489,7 +489,7 @@ class PdbReader:
         """Strips unnecessary components from the start of a symbol name."""
         new_name = name
 
-        if new_name[:1] in ["_", "@", "\u007F"]:
+        if new_name[:1] in ["_", "@", "\u007f"]:
             new_name = new_name[1:]
 
         name_array = new_name.split("@")
